<?php
// $Id$

/**
 * CSS Reset and default styling
 */
drupal_add_css(drupal_get_path('theme', 'layoutstudio') . '/css/defaults.css', array('weight' => CSS_THEME, 'type' => 'file'));
drupal_add_css(drupal_get_path('theme', 'WORKING_COPY') . '/css/defaults_ie.css', array('weight' => CSS_THEME, 'browsers' => array('IE' => 'lt IE 9', '!IE' => FALSE), 'preprocess' => FALSE));

function layoutstudio_preprocess_html(&$variables) {
  // Set up layout variable.
  $variables['layout'] = 'no-secondary-and-tertiary';
  if (!empty($variables['page']['secondary_first']) OR !empty($variables['page']['secondary']) OR !empty($variables['page']['secondary_last'])) {
    $variables['layout'] = 'no-tertiary';
  }
  if (!empty($variables['page']['tertiary_first']) OR !empty($variables['page']['tertiary']) OR !empty($variables['page']['tertiary_last'])) {
    $variables['layout'] = ($variables['layout'] == 'no-tertiary') ? 'regions-all' : 'no-secondary';
  }
  $variables['preface_class'] = 'no-preface';
  if (!empty($variables['page']['preface_first']) OR !empty($variables['page']['preface']) OR !empty($variables['page']['preface_last'])) {
    $variables['preface_class'] = 'no-preface';
  }
  $variables['postscript_class'] = 'no-postscript';
  if (!empty($variables['page']['postscript_first']) OR !empty($variables['page']['postscript']) OR !empty($variables['page']['postscript_last'])) {
    $variables['postscript_class'] = 'no-postscript';
  }

  // Compile an array of classes that are going to be applied to the body element.
  // This allows advanced theming based on context (home page, node of certain type, etc.).
  // Random body class
  $random = theme_get_setting('layoutstudio_random_class');
  if ($random > 1){
    $variables['classes_array'][] = 'random-'.rand(1, $random);
  }
  // Current active menu item
 	$variables['classes_array'][] = 'menu-item-'. drupal_clean_css_identifier(drupal_strtolower(menu_get_active_title()));
  // Add information regarding the secondary & tertiary.
  if ($variables['layout'] == 'regions-all') {
    $variables['classes_array'][] = 'regions-all';
  }
  elseif ($variables['layout'] == 'no-secondary-and-tertiary') {
    $variables['classes_array'][] = 'no-secondary-and-tertiary';
  }
  else {
    $variables['classes_array'][] = $variables['layout'];
  }
  $variables['classes_array'][] = $variables['preface_class'];
  $variables['classes_array'][] = $variables['postscript_class'];

  if (!$variables['is_front']) {
		// Add unique classes for each page and website section
		$path = drupal_get_path_alias($_GET['q']);
    $section = arg(0);
    $sub_section = arg(1);
		$variables['classes_array'][] = 'section-'. $section;
		$variables['classes_array'][] = 'sub-section-'. ($sub_section ? $sub_section : 'none');
		if (arg(0) == 'node') {
			if (arg(1) == 'add') {
				if ($section == 'node') {
					array_pop($variables['classes_array']); // Remove 'section-node'
					array_pop($variables['classes_array']); // Remove 'section-node'
				}
				$variables['classes_array'][] = 'section-node-add'; // Add 'section-node-add'
			}
			elseif (is_numeric(arg(1)) && (arg(2) == 'edit' || arg(2) == 'delete')) {
				if ($section == 'node') {
					array_pop($variables['classes_array']); // Remove 'section-node'
					array_pop($variables['classes_array']); // Remove 'section-node'
				}
				$variables['classes_array'][] = 'section-node-'. arg(2); // Add 'section-node-edit' or 'section-node-delete'
			}
		}
	}
}

//Setting classes for body element
function layoutstudio_preprocess_page(&$variables) {
	// Set up layout variable.
  $variables['layout'] = 'no-secondary-and-tertiary';
  if (!empty($variables['page']['secondary_first']) OR !empty($variables['page']['secondary']) OR !empty($variables['page']['secondary_last'])) {
    $variables['layout'] = 'no-tertiary';
  }
  if (!empty($variables['page']['tertiary_first']) OR !empty($variables['page']['tertiary']) OR !empty($variables['page']['tertiary_last'])) {
    $variables['layout'] = ($variables['layout'] == 'no-tertiary') ? 'regions-all' : 'no-secondary';
  }
  $variables['preface_classes_array'] = 'no-preface';
  if (!empty($variables['page']['preface_first']) OR !empty($variables['page']['preface']) OR !empty($variables['page']['preface_last'])) {
    $variables['preface_classes_array'] = 'no-preface';
  }
  $variables['postscript_classes_array'] = 'no-postscript';
  if (!empty($variables['page']['postscript_first']) OR !empty($variables['page']['postscript']) OR !empty($variables['page']['postscript_last'])) {
    $variables['postscript_classes_array'] = 'no-postscript';
  }
}

//Setting classes for nodes
function layoutstudio_preprocess_node(&$variables) {
  global $user;

	// Compile an array of classes that are going to be applied to the node div.
	if ($variables['node']->uid && $variables['node']->uid == $user->uid) {
		// Node is authored by current user
		$variables['classes_array'][] = 'user-me';
	}
	//Add node's user id
	$variables['classes_array'][] = 'user-' . $variables['node']->uid;

	if ($variables['teaser']) {
		// Node is displayed as teaser
    $variables['classes_array'][] = 'node-'. $variables['node']->type.'-teaser';
	}
	else {
		$variables['classes_array'][] = 'node-full';
    $variables['classes_array'][] = 'node-'. $variables['node']->type.'-full';
	}
	//odd/even class for node listings
	$variables['classes_array'][] = $variables['zebra'];
	//node count for node listings
	$variables['classes_array'][] = 'count-' . $variables['id'];
	//Add clear fix class
	$variables['classes_array'][] = 'clearfix';
}

//Setting classes for blocks
function layoutstudio_preprocess_block(&$variables) {
  // Random block class
  $random = theme_get_setting('layoutstudio_random_class');
  if ($random > 1){
    $variables['classes_array'][] = 'random-'.rand(1, $random);
  }
  $variables['classes_array'][] = $variables['block_zebra'];
  $variables['classes_array'][] = 'region-count-'. $variables['block_id'];
	//Add clear fix class
	$variables['classes_array'][] = 'clearfix';
}

// Setting classes for comments
function layoutstudio_preprocess_comment(&$variables) {
  static $comment_counter = array();

  if (!isset($comment_counter[$variables['node']->nid])) {
    $comment_counter[$variables['node']->nid] = 1;
  }
  $variables['classes_array'][] = ($comment_counter[$variables['node']->nid] % 2) ? 'odd' : 'even';
  $variables['classes_array'][] = 'comment-'.$variables['comment']->cid;
  $comment_counter[$variables['node']->nid]++;
}